pub(crate) struct Opts {
pub(crate) log_level: LogLevelOpts,
pub(crate) config: Option<PathBuf>,
pub(crate) subcommand: SubCommand,
}Expand description
Database migration for evobench: update storage format for jobs in
queues. Run this when you’re getting deserialisation errors from
evobench, or when you know that the data structures have
changed and will cause errors.
Fields
log_level: LogLevelOptsconfig: Option<PathBuf>Override the path to the config file (default: the paths
~/.evobench.* where a single one exists where the * is
the suffix for one of the supported config file formats (run
config-formats to get the list), and if those are missing,
use compiled-in default config values)
subcommand: SubCommandThe subcommand to run. Use --help after the sub-command to
get a list of the allowed options there.